from setuptools import setup

setup(
  name='hr-commons',
  packages=['hrcommons'],
  version='0.1',
  description=("Common code for HR"),
  author='Joshua "jag" Ginsberg',
  author_email='jag@flowtheory.net',
  install_requires=[]
)

print("Don't install public packages from PyPI you don't know what they are!")
